@@ -1,6 +1,6 @@
 /* GCSAlarmsFolder.m - this file is part of SOGo
  *
- * Copyright (C) 2010-2014 Inverse inc.
+ * Copyright (C) 2010-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,16 +18,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#import <Foundation/NSDictionary.h>
-#import <Foundation/NSString.h>
-#import <Foundation/NSURL.h>
-#import <Foundation/NSUserDefaults.h>
-#import <Foundation/NSValue.h>
 
 #import <NGExtensions/NSObject+Logs.h>
 #import <NGExtensions/NSNull+misc.h>
 
-#import <GDLAccess/EOAdaptorChannel.h>
 #import <GDLAccess/EOAdaptorContext.h>
 #import <GDLAccess/EOAttribute.h>
 #import <GDLAccess/EOEntity.h>
@@ -37,7 +31,6 @@
 #import "GCSChannelManager.h"
 #import "GCSFolderManager.h"
 #import "GCSSpecialQueries.h"
-#import "GCSStringFormatter.h"
 #import "NSURL+GCS.h"
 
 #import "GCSAlarmsFolder.h"
@@ -416,36 +409,4 @@ static NSString *alarmsFolderURLString = nil;
     }
 }
 
-- (void) deleteRecordsForEntriesUntilDate: (NSCalendarDate *) date
-{
-  EOAdaptorChannel *tc;
-  EOAdaptorContext *context;
-  EOEntity *entity;
-  EOSQLQualifier *qualifier;
-  NSException *error;
-
-  tc = [self _acquireStoreChannel];
-  if (tc)
-    {
-      context = [tc adaptorContext];
-      entity = [self _storeTableEntityForChannel: tc];
-      qualifier = [[EOSQLQualifier alloc] initWithEntity: entity
-                                         qualifierFormat:
-                                            @"c_alarm_date <= %d",
-                                          (int) [date timeIntervalSince1970]];
-      [qualifier autorelease];
-      [context beginTransaction];
-      error = [tc deleteRowsDescribedByQualifierX: qualifier];
-      if (error)
-        {
-          [context rollbackTransaction];
-          [self errorWithFormat:@"%s: cannot delete record: %@", 
-                __PRETTY_FUNCTION__, error];
-        }
-      else
-        [context commitTransaction];
-      [self _releaseChannel: tc];
-    }
-}
-
 @end
