@@ -20,15 +20,15 @@
 */
 
 #import <Foundation/NSArray.h>
-#import <Foundation/NSString.h>
+#import <Foundation/NSException.h>
 #import <Foundation/NSURL.h>
 #import <Foundation/NSValue.h>
 
 #import "NSCalendarDate+NGCards.h"
 
 #import "iCalAlarm.h"
+#import "iCalCalendar.h"
 #import "iCalDateTime.h"
-#import "iCalEntityObject.h"
 #import "iCalEvent.h"
 #import "iCalPerson.h"
 
@@ -268,9 +268,12 @@
 - (void) setRecurrenceId: (NSCalendarDate *) newRecId
 {
   iCalDateTime* recurrenceId;
+  BOOL isMasterAllDay;
+
+  isMasterAllDay = [[[[self parent] events] objectAtIndex: 0] isAllDay];
 
   recurrenceId = (iCalDateTime *) [self uniqueChildWithTag: @"recurrence-id"];
-  if ([self isKindOfClass: [iCalEvent class]] && [(iCalEvent *)self isAllDay])
+  if ([self isKindOfClass: [iCalEvent class]] && isMasterAllDay)
     [recurrenceId setDate: newRecId];
   else
     [recurrenceId setDateTime: newRecId];
@@ -400,32 +403,58 @@
   return [self childrenWithTag: @"valarm"];
 }
 
-- (void) setAttach: (id) _value
+- (void) setAttach: (NSArray *) _value
 {
   NSString *aString;
+  id anObject;
+  int count, max;
 
-  if ([_value isKindOfClass: [NSString class]])
-    aString = _value;
-  else if ([_value isKindOfClass: [NSURL class]])
-    aString = [_value absoluteString];
-  else
-    aString = @"";
-
-  [[self uniqueChildWithTag: @"attach"] setSingleValue: aString forKey: @""];
+  max = [_value count];
+  for (count = 0; count < max; count++)
+    {
+      anObject = [_value objectAtIndex: count];
+      if ([anObject isKindOfClass: [NSURL class]])
+        {
+          aString = [anObject absoluteString];
+        }
+      else
+        aString = anObject;
+      [self addChild: [CardElement simpleElementWithTag: @"attach" value: aString]];
+    }
 }
 
-- (NSURL *) attach
+- (NSArray *) attach
 {
+  NSArray *elements;
+  NSMutableArray *attachUrls;
   NSString *stringAttach;
   NSURL *url;
+  int count, max;
 
-  stringAttach = [[self uniqueChildWithTag: @"attach"] flattenedValuesForKey: @""];
-  url = [NSURL URLWithString: stringAttach];
+  elements = [self childrenWithTag: @"attach"];
+  max = [elements count];
+  attachUrls = [NSMutableArray arrayWithCapacity: max];
+  for (count = 0; count < max; count++)
+    {
+      stringAttach = [[elements objectAtIndex: count] flattenedValuesForKey: @""];
 
-  if (!url && [stringAttach length] > 0)
-    url = [NSURL URLWithString: [NSString stringWithFormat: @"http://%@", stringAttach]];
+      NS_DURING
+        {
+          url = [NSURL URLWithString: stringAttach];
+
+          if (![url scheme] && [stringAttach length] > 0)
+            url = [NSURL URLWithString: [NSString stringWithFormat: @"http://%@", stringAttach]];
+
+          [attachUrls addObject: [url absoluteString]];
+        }
+      NS_HANDLER
+        {
+          // Invalid URL, skipping.
+        }
+      NS_ENDHANDLER
+    }
   
-  return url;
+  return attachUrls;
 }
 
 - (void) setUrl: (id) _value
