@@ -1045,7 +1045,7 @@ static NSCharacterSet *whitespaceCharSet = nil;
   if (debugOn)
     {
       NSLog(@"%s: trying to decode data (0x%p,len=%d) ...",
-	    __PRETTY_FUNCTION__, _data, [_data length]);
+	    __PRETTY_FUNCTION__, _data, (int)[_data length]);
     }
   
   if ((len = [_data length]) == 0)
@@ -1075,6 +1075,12 @@ static NSCharacterSet *whitespaceCharSet = nil;
   // FIXME: Data is not always utf-8.....
   source = [[[NSString alloc] initWithData: _data encoding: encoding]
 	     autorelease];
+
+  // We fallback to ISO-8859-1 string encoding
+  if (!source)
+     source = [[[NSString alloc] initWithData: _data encoding: NSISOLatin1StringEncoding]
+                 autorelease];
+
   if (!source)
     {
       e = (id)[SaxParseException exceptionWithName: @"SaxIOException"
@@ -1158,7 +1164,7 @@ static NSCharacterSet *whitespaceCharSet = nil;
   if (debugOn)
     {
       NSLog(@"%s: trying to parse string (0x%p,len=%d) ...",
-            __PRETTY_FUNCTION__, _source, [_source length]);
+            __PRETTY_FUNCTION__, _source, (int)[_source length]);
     }
   if (!_sysId) _sysId = @"<string>";
   [self _parseString: _source];
