@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2007-2019 Inverse inc.
+  Copyright (C) 2007-2020 Inverse inc.
 
   This file is part of SOGo
 
@@ -54,6 +54,7 @@
 #import <SOGo/WORequest+SOGo.h>
 
 #import "iCalCalendar+SOGo.h"
+#import "iCalEvent+SOGo.h"
 #import "iCalEventChanges+SOGo.h"
 #import "iCalEntityObject+SOGo.h"
 #import "iCalPerson+SOGo.h"
@@ -768,13 +769,15 @@
           
           if ([user isResource])
             {
-              // If we always force the auto-accept if numberOfSimultaneousBookings <= 0 (ie., no limit
+              // We always force the auto-accept if numberOfSimultaneousBookings <= 0 (ie., no limit
               // is imposed) or if numberOfSimultaneousBookings is greater than the number of
-              // overlapping events
+              // overlapping events.
+              // When numberOfSimultaneousBookings is set to -1, only force the auto-accept
+              // once the conflict has been raised and the action is forced by the user.
               if ([user numberOfSimultaneousBookings] <= 0 ||
                   [user numberOfSimultaneousBookings] > [fbInfo count])
                 {
-                  if (currentAttendee)
+                  if (currentAttendee && ([user numberOfSimultaneousBookings] >= 0 || forceSave))
                     {
                       [[currentAttendee attributes] removeObjectForKey: @"RSVP"];
                       [currentAttendee setParticipationStatus: iCalPersonPartStatAccepted];
@@ -811,7 +814,7 @@
           // We are dealing with a normal attendee. Lets check if we have conflicts, unless
           // we are being asked to force the save anyway
           //
-          else if (!forceSave)
+          if (!forceSave && !_resourceHasAutoAccepted)
             {
               NSMutableDictionary *info;
               NSMutableArray *conflicts;
@@ -865,7 +868,7 @@
           // set the resource as one!
           [[currentAttendee attributes] removeObjectForKey: @"RSVP"];
           [currentAttendee setParticipationStatus: iCalPersonPartStatAccepted];
-	  _resourceHasAutoAccepted = YES;
+          _resourceHasAutoAccepted = YES;
         }
     }
 
@@ -1930,6 +1933,7 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
 {
   NSArray *allEvents;
   iCalEvent *event;
+  iCalTimeZone *tz;
   NSUInteger i;
   int j;
 
@@ -1939,15 +1943,9 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
     {
       event = [allEvents objectAtIndex: i];
 
-      if (![event hasEndDate] && ![event hasDuration])
-        {
-          // No end date, no duration
-          if ([event isAllDay])
-            [event setDuration: @"P1D"];
-          else
-            [event setDuration: @"PT1H"];
-          [self warnWithFormat: @"Invalid event: no end date; setting duration to %@", [event duration]];
-        }
+      tz = [event adjustInContext: context];
+      if (tz)
+        [rqCalendar addTimeZone: tz];
 
       if ([event organizer])
         {
@@ -1994,53 +1992,6 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
     }
 }
 
-//
-// This is similar to what we do in SOGoAppointmentFolder: -importCalendar:
-//
-- (void) _adjustFloatingTimeInRequestCalendar: (iCalCalendar *) rqCalendar
-{
-  iCalDateTime *startDate, *endDate;
-  NSString *startDateAsString;
-  SOGoUserDefaults *ud;
-  NSArray *allEvents;
-  iCalTimeZone *tz;
-  iCalEvent *event;
-  int i, delta;
-
-  allEvents = [rqCalendar events];
-  for (i = 0; i < [allEvents count]; i++)
-    {
-      event = [allEvents objectAtIndex: i];
-
-      if ([event isAllDay])
-	continue;
-
-      startDate =  (iCalDateTime *)[event uniqueChildWithTag: @"dtstart"];
-      startDateAsString = [[startDate valuesAtIndex: 0 forKey: @""] objectAtIndex: 0];
-
-      if (![startDate timeZone] &&
-	  ![startDateAsString hasSuffix: @"Z"] &&
-	  ![startDateAsString hasSuffix: @"z"])
-	{
-	  ud = [[context activeUser] userDefaults];
-          tz = [iCalTimeZone timeZoneForName: [ud timeZoneName]];
-          if ([rqCalendar addTimeZone: tz])
-            {
-	      delta = [[tz periodForDate: [startDate dateTime]] secondsOffsetFromGMT];
-
-	      [event setStartDate: [[event startDate] dateByAddingYears: 0  months: 0  days: 0  hours: 0  minutes: 0  seconds: -delta]];
-	      [startDate setTimeZone: tz];
-
-	      endDate = (iCalDateTime *) [event uniqueChildWithTag: @"dtend"];
-	      if (endDate)
-		{
-		  [event setEndDate: [[event endDate] dateByAddingYears: 0  months: 0  days: 0  hours: 0  minutes: 0  seconds: -delta]];
-		  [endDate setTimeZone: tz];
-		}
-            }
-	}
-    }
-}
 
 - (void) _decomposeGroupsInRequestCalendar: (iCalCalendar *) rqCalendar
 {
@@ -2123,21 +2074,6 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
   return [super DELETEAction: _ctx];
 }
 
-//
-// Let's check if our CalDAV client has sent us a broken SENT-BY. When Lightning is identity-aware,
-// it'll stupidly send something like this:
-// ORGANIZER;RSVP=TRUE;CN=John Doe;PARTSTAT=ACCEPTED;ROLE=CHAIR;SENT-BY="mail
-// to:mailto:sogo3@example.com":mailto:sogo1@example.com
-//
-- (void) _fixupSentByForPerson: (iCalPerson *) person
-{
-  NSString *sentBy;
-
-  sentBy = [person sentBy];
-  if ([sentBy hasPrefix: @"mailto:"])
-    [person setSentBy: [sentBy substringFromIndex: 7]];
-}
-
 //
 // This method is meant to be the common point of any save operation from web
 // and DAV requests, as well as from code making use of SOGo as a library
@@ -2178,7 +2114,6 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
       [self _adjustEventsInRequestCalendar: calendar];
       [self adjustClassificationInRequestCalendar: calendar];
       [self _adjustPartStatInRequestCalendar: calendar];
-      [self _adjustFloatingTimeInRequestCalendar: calendar];
     }
       
   //
@@ -2226,8 +2161,6 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
 	  attendees = [event attendeesWithoutUser: ownerUser];
 	  if ([attendees count])
 	    {
-	      [self _fixupSentByForPerson: [event organizer]];
-
 	      if ((ex = [self _handleAddedUsers: attendees fromEvent: event  force: YES]))
 		return ex;
 	      else
@@ -2405,8 +2338,6 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
 	      // We check ACLs of the 'organizer' - in case someone forges the SENT-BY
 	      NSString *uid;
 
-	      [self _fixupSentByForPerson: [newEvent organizer]];
-
 	      uid = [[oldEvent organizer] uidInContext: context];
 
 	      if (uid && [[[context activeUser] login] caseInsensitiveCompare: uid] != NSOrderedSame)
@@ -2486,7 +2417,8 @@ inRecurrenceExceptionsForEvent: (iCalEvent *) theEvent
               
               if ([delegateEmail length])
                 {
-                  delegateEmail = [delegateEmail substringFromIndex: 7];
+                  if ([[delegateEmail lowercaseString] hasPrefix: @"mailto:"])
+                    delegateEmail = [delegateEmail substringFromIndex: 7];
                   if ([delegateEmail length])
                     delegate = [newEvent findAttendeeWithEmail: delegateEmail];
                 }
