@@ -1,6 +1,6 @@
 /* NSString+Mail.m - this file is part of SOGo
  *
- * Copyright (C) 2008-2014 Inverse inc.
+ * Copyright (C) 2008-2018 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -262,6 +262,7 @@
            attributes: (id <SaxAttributes>) attributes
 {
   NSString *tagName;
+  BOOL appendElement = YES;
 
   showWhoWeAre();
 
@@ -295,7 +296,7 @@
               NSData *data;
               id body;
 
-              int i, j, k;
+              int i, j, k, len;
 
               i = [value indexOf: ';'];
               j = [value indexOf: ';' fromIndex: i+1];
@@ -326,17 +327,39 @@
                 encoding = @"base64";
 
               data = [[value substringFromIndex: k+1] dataUsingEncoding: NSASCIIStringEncoding];
+              len = [data length];
+              if ([encoding isEqualToString: @"base64"] && len > 72)
+                {
+                  NSMutableData *folded_data;
+                  unsigned char *bytes, c;
+
+                  folded_data = [NSMutableData data];
+                  bytes = (unsigned char *)[data bytes];
+
+                  for (i = 0; i < len; i++)
+                    {
+                      if (i > 0 && i % 72 == 0)
+                        {
+                          c = '\n';
+                          [folded_data appendBytes: &c  length: 1];
+                        }
+
+                      c = *bytes; bytes++;
+                      [folded_data appendBytes: &c  length: 1];
+                    }
+
+                  data = folded_data;
+                }
 
               uniqueId = [SOGoObject globallyUniqueObjectId];
 
-              map = [[[NGMutableHashMap alloc] initWithCapacity:5] autorelease];
+              map = [[[NGMutableHashMap alloc] initWithCapacity: 5] autorelease];
               [map setObject: encoding forKey: @"content-transfer-encoding"];
-              [map setObject:[NSNumber numberWithInt:[data length]] forKey: @"content-length"];
+              [map setObject:[NSNumber numberWithInt: [data length]] forKey: @"content-length"];
               [map setObject: [NSString stringWithFormat: @"inline; filename=\"%@\"", uniqueId]  forKey: @"content-disposition"];
               [map setObject: [NSString stringWithFormat: @"%@; name=\"%@\"", mimeType, uniqueId]  forKey: @"content-type"];
               [map setObject: [NSString stringWithFormat: @"<%@>", uniqueId]  forKey: @"content-id"];
 
-
               body = [[NGMimeFileData alloc] initWithBytes: [data bytes]  length: [data length]];
 
               bodyPart = [[[NGMimeBodyPart alloc] initWithHeader:map] autorelease];
@@ -359,9 +382,11 @@
                 }
 
               [result appendString: @"/>"];
+
+              appendElement = NO;
             }
         }
-      else if (voidTags)
+      if (appendElement && voidTags)
         {
           NSString *type;
           int i;
@@ -710,4 +735,33 @@ convertChars (const char *oldString, unsigned int oldLength,
   return safeName;
 }
 
+//
+// We might end up here because of MUA that actually strips the
+// Content-Disposition (and thus, the filename) when mails containing
+// attachments have been forwarded. Thunderbird (2.x) does just that
+// when forwarding mails with images attached to them (using cid:...).
+//
+- (NSString *) asPreferredFilenameUsingPath: (NSString *) thePath
+{
+  NSString *filename;
+
+  filename = nil;
+  if (!thePath)
+    thePath = @"1";
+
+  if ([self hasPrefix: @"application/"] ||
+      [self hasPrefix: @"audio/"] ||
+      [self hasPrefix: @"image/"] ||
+      [self hasPrefix: @"video/"])
+    {
+      filename = [NSString stringWithFormat: @"unknown_%@", thePath];
+    }
+  else
+    {
+      if ([self isEqualToString: @"message/rfc822"])
+        filename = [NSString stringWithFormat: @"email_%@.eml", thePath];
+    }
+
+  return filename;
+}
 @end
