@@ -61,6 +61,11 @@
   NSString *sourceFlag;
   NSString *sourceFolder;
   BOOL isHTML;
+  BOOL sign;
+  BOOL encrypt;
+
+  // Used during S/MIME encryption
+  NSMutableDictionary *certificates;
 }
 
 /* contents */
@@ -79,6 +84,13 @@
 - (void) setIsHTML: (BOOL) aBool;
 - (BOOL) isHTML;
 
+- (void) setSign: (BOOL) aBool;
+- (BOOL) sign;
+
+- (void) setEncrypt: (BOOL) aBool;
+- (BOOL) encrypt;
+
+
 /* for replies and forwards */
 - (NSString *) inReplyTo;
 - (void) setInReplyTo: (NSString *) newInReplyTo;
@@ -105,8 +117,7 @@
 
 /* NGMime representations */
 
-- (NGMimeMessage *) mimeMessage;
-- (NSData *) mimeMessageAsData;
+- (NSData *) mimeMessageForRecipient: (NSString *) theRecipient;
 
 /* operations */
 - (NSArray *) allRecipients;
