@@ -872,6 +872,18 @@ static NSString    *userAgent      = nil;
 }
 
 
+//
+//
+//
+- (void) _fetchAttachmentsFromOpaqueSignedMail: (SOGoMailObject *) sourceMail
+{
+  NGMimeMessage *m;
+
+  m = [[sourceMail content] messageFromOpaqueSignedData];
+  [self _fileAttachmentsFromPart: [m body]];
+}
+
+
 //
 //
 //
@@ -1007,6 +1019,8 @@ static NSString    *userAgent      = nil;
       [self setText: [sourceMail contentForInlineForward]];
       if ([sourceMail isEncrypted])
         [self _fetchAttachmentsFromEncryptedMail: sourceMail];
+      else if ([sourceMail isOpaqueSigned])
+        [self _fetchAttachmentsFromOpaqueSignedMail: sourceMail];
       else
         [self _fetchAttachmentsFromMail: sourceMail];
     }
@@ -2054,7 +2068,7 @@ static NSString    *userAgent      = nil;
           if (!error)
             {
               [self imap4Connection];
-              if (IMAP4ID > -1)
+              if (IMAP4ID > -1 && ![dd mailKeepDraftsAfterSend])
                 [imap4 markURLDeleted: [self imap4URL]];
               if (sourceURL && sourceFlag)
                 {
