@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2007-2016 Inverse inc.
+  Copyright (C) 2007-2019 Inverse inc.
 
   This file is part of SOGo.
 
@@ -300,19 +300,32 @@ static NSString *inboxFolderName = @"INBOX";
   return inboxQuota;
 }
 
-- (BOOL) updateFilters
+- (NSException *) updateFiltersAndForceActivation: (BOOL) forceActivation
 {
-  return [self updateFiltersWithUsername: nil andPassword: nil];
+  return [self updateFiltersWithUsername: nil
+                             andPassword: nil
+                         forceActivation: forceActivation];
 }
 
-- (BOOL) updateFiltersWithUsername: (NSString *) theUsername
+- (NSException *) updateFilters
+{
+  return [self updateFiltersWithUsername: nil
+                             andPassword: nil
+                         forceActivation: NO];
+}
+
+- (NSException *) updateFiltersWithUsername: (NSString *) theUsername
                        andPassword: (NSString *) thePassword
+                   forceActivation: (BOOL) forceActivation
 {
   SOGoSieveManager *manager;
 
   manager = [SOGoSieveManager sieveManagerForUser: [context activeUser]];
 
-  return [manager updateFiltersForAccount: self  withUsername: theUsername  andPassword: thePassword];
+  return [manager updateFiltersForAccount: self
+                             withUsername: theUsername
+                              andPassword: thePassword
+                          forceActivation: forceActivation];
 }
 
 
