@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2009-2017 Inverse inc.
+  Copyright (C) 2009-2019 Inverse inc.
   Copyright (C) 2004-2005 SKYRIX Software AG
 
   This file is part of SOGo.
@@ -58,8 +58,10 @@
 #import <SOGo/NSObject+DAV.h>
 #import <SOGo/SOGoPermissions.h>
 #import <SOGo/SOGoSystemDefaults.h>
+#import <SOGo/SOGoGroup.h>
 #import <SOGo/SOGoUser.h>
 #import <SOGo/SOGoUserFolder.h>
+#import <SOGo/SOGoUserManager.h>
 #import <SOGo/SOGoUserSettings.h>
 #import <SOGo/WORequest+SOGo.h>
 #import <SOGo/WOResponse+SOGo.h>
@@ -882,7 +884,6 @@ _compareFetchResultsByMODSEQ (id entry1, id entry2, void *data)
               // We reached the limit or the end of the array
               if ((i%limit) == 0 || i == [uids count]-1)
                 {
-                  id <SOGoAuthenticator> authenticator;
                   NGMimeMessageGenerator *generator;
 
                   [messageToSend setBody: body];
@@ -890,13 +891,11 @@ _compareFetchResultsByMODSEQ (id entry1, id entry2, void *data)
                   generator = [[[NGMimeMessageGenerator alloc] init] autorelease];
                   data = [generator generateMimeFromPart: messageToSend];
 
-                  authenticator = [SOGoDAVAuthenticator sharedSOGoDAVAuthenticator];
-
                   error = [[SOGoMailer mailerWithDomainDefaults: [[context activeUser] domainDefaults]]
                             sendMailData: data
                             toRecipients: [NSArray arrayWithObject: recipient]
                                   sender: [[identities objectAtIndex: 0] objectForKey: @"email"]
-                            withAuthenticator: authenticator
+                            withAuthenticator: [self authenticatorInContext: context]
                                inContext: context];
 
                   if (error)
@@ -1423,15 +1422,29 @@ _compareFetchResultsByMODSEQ (id entry1, id entry2, void *data)
 
 - (NSString *) _sogoACLUIDToIMAPUID: (NSString *) uid
 {
+  SOGoGroup *group;
+  SOGoUser *user;
+
+  if ([uid isEqualToString: defaultUserID])
+    return uid;
+
+  group = [SOGoGroup groupWithIdentifier: uid
+                                inDomain: [[context activeUser] domain]];
+  if (group)
+    return [[[[context activeUser] domainDefaults] imapAclGroupIdPrefix]
+             stringByAppendingString: uid];
+
+  user = [SOGoUser userWithLogin: uid];
+
   if ([uid hasPrefix: @"@"])
     return [[[[context activeUser] domainDefaults] imapAclGroupIdPrefix]
              stringByAppendingString: [uid substringFromIndex: 1]];
   else if ([[[context activeUser] domainDefaults] forceExternalLoginWithEmail])
-    {
-      return [[[SOGoUser userWithLogin: uid] primaryIdentity] objectForKey: @"email"];
-    }
-  else
-    return uid;
+      return [[user primaryIdentity] objectForKey: @"email"];
+
+  return [[SOGoUserManager sharedUserManager]
+                     getExternalLoginForUID: [user loginInDomain]
+                                   inDomain: [user domain]];
 }
 
 - (void) _removeIMAPExtUsernames
