@@ -67,6 +67,7 @@
 
   NSString *_domain;
   NSString *_contactInfoAttribute;
+  BOOL _groupExpansionEnabled;
 
   NSDictionary *_contactMapping;
   NSArray *_contactObjectClasses;
@@ -125,6 +126,8 @@ andMultipleBookingsField: (NSString *) newMultipleBookingsField;
 
 - (void) updateBaseDNFromLogin: (NSString *) theLogin;
 
+- (BOOL) groupExpansionEnabled;
+
 @end
 
 #endif /* LDAPSOURCE_H */
