@@ -165,7 +165,7 @@ static Class NSStringK;
                inDomain: (NSString *) sourceDomain
 {
   SOGoDomainDefaults *dd;
-  NSNumber *udQueryLimit, *udQueryTimeout, *dotValue;
+  NSNumber *udQueryLimit, *udQueryTimeout, *udGroupExpansionEnabled, *dotValue;
 
   if ((self = [self init]))
     {
@@ -238,6 +238,14 @@ static Class NSStringK;
       else
         _queryTimeout = [dd ldapQueryTimeout];
 
+      if ([[udSource allKeys] containsObject: @"SOGoLDAPGroupExpansionEnabled"])
+        {
+          udGroupExpansionEnabled = [udSource objectForKey: @"SOGoLDAPGroupExpansionEnabled"];
+          _groupExpansionEnabled = [udGroupExpansionEnabled boolValue];
+        }
+      else
+        _groupExpansionEnabled = [dd ldapGroupExpansionEnabled];
+
       ASSIGN(_modulesConstraints, [udSource objectForKey: @"ModulesConstraints"]);
       ASSIGN(_filter, [udSource objectForKey: @"filter"]);
       ASSIGN(_userPasswordAlgorithm, [udSource objectForKey: @"userPasswordAlgorithm"]);
@@ -426,7 +434,7 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
 
   NS_DURING
     {
-      NSLog(@"Creating NGLdapConnection instance for bindDN '%@'", _bindDN);
+      //NSLog(@"Creating NGLdapConnection instance for bindDN '%@'", _bindDN);
       ldapConnection = [[NGLdapConnection alloc] initWithHostName: _hostname
                                                              port: _port];
       [ldapConnection autorelease];
@@ -609,7 +617,8 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
 - (NSString *) _encryptPassword: (NSString *) thePassword
 {
   NSString *pass;
-  pass = [thePassword asCryptedPassUsingScheme: _userPasswordAlgorithm];
+  pass = [thePassword asCryptedPassUsingScheme: _userPasswordAlgorithm
+                                       keyPath: nil];
 
   if (pass == nil)
     {
@@ -1461,6 +1470,11 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return _groupObjectClasses;
 }
 
+- (BOOL) groupExpansionEnabled
+{
+  return _groupExpansionEnabled;
+}
+
 static NSArray *
 _convertRecordToLDAPAttributes (LDAPSourceSchema *schema, NSDictionary *ldifRecord)
 {
