@@ -1,6 +1,6 @@
 /* SOGoDomainDefaults.h - this file is part of SOGo
  *
- * Copyright (C) 2009-2015 Inverse inc.
+ * Copyright (C) 2009-2019 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,13 +44,20 @@
 - (NSString *) imapCASServiceName;
 - (NSString *) imapAclStyle;
 - (NSString *) imapAclGroupIdPrefix;
-- (NSString *) imapFolderSeparator;
 - (BOOL) imapAclConformsToIMAPExt;
 - (BOOL) forceExternalLoginWithEmail;
+- (BOOL) externalAvatarsEnabled;
 - (BOOL) sieveScriptsEnabled;
+- (NSString *) sieveScriptHeaderTemplateFile;
+- (NSString *) sieveScriptFooterTemplateFile;
 - (BOOL) forwardEnabled;
 - (int) forwardConstraints;
+- (NSArray *) forwardConstraintsDomains;
 - (BOOL) vacationEnabled;
+- (BOOL) vacationPeriodEnabled;
+- (NSString *) vacationDefaultSubject;
+- (NSString *) vacationHeaderTemplateFile;
+- (NSString *) vacationFooterTemplateFile;
 - (NSString *) mailingMechanism;
 - (NSString *) smtpServer;
 - (NSString *) smtpAuthenticationType;
@@ -68,11 +75,11 @@
 - (NSArray *) refreshViewIntervals;
 - (NSString *) subscriptionFolderFormat;
 
-- (NSString *) calendarDefaultCategoryColor;
-
 - (NSArray *) freeBusyDefaultInterval;
 - (int) davCalendarStartTimeLimit;
 
+- (BOOL) ldapGroupExpansionEnabled;
+
 - (BOOL) iPhoneForceAllDayTransparency;
 
 - (NSArray *) additionalJSFiles;
@@ -83,6 +90,8 @@
 - (BOOL) notifyOnPersonalModifications;
 - (BOOL) notifyOnExternalModifications;
 
+- (NSDictionary *) mailJunkSettings;
+
 @end
 
 #endif /* SOGODOMAINDEFAULTS_H */
