@@ -23,7 +23,6 @@
 #ifndef __SoObjects_SOGoObject_H__
 #define __SoObjects_SOGoObject_H__
 
-#import <Foundation/NSObject.h>
 
 #if LIB_FOUNDATION_LIBRARY
 #error SOGo will not work properly with libFoundation.
@@ -83,6 +82,8 @@
 
 - (BOOL) isInPublicZone;
 
+- (BOOL) doesRetainContainer;
+
 /* accessors */
 
 - (void) setContext: (WOContext *) newContext;
