@@ -542,6 +542,16 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
   return [self stringForKey: @"SOGoAnimationMode"];
 }
 
+- (void) setMailComposeWindow: (NSString *) newValue
+{
+  [self setObject: newValue forKey: @"SOGoMailComposeWindow"];
+}
+
+- (NSString *) mailComposeWindow
+{
+  return [self stringForKey: @"SOGoMailComposeWindow"];
+}
+
 - (void) setMailComposeMessageType: (NSString *) newValue
 {
   [self setObject: newValue forKey: @"SOGoMailComposeMessageType"];
@@ -729,6 +739,41 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
   return [self boolForKey: @"SOGoMailUseOutlookStyleReplies"];
 }
 
+- (void) setMailCertificate: (NSData *) newValue
+{
+  [self setObject: [newValue stringByEncodingBase64] forKey: @"SOGoMailCertificate"];
+}
+
+- (void) unsetMailCertificate
+{
+  [self removeObjectForKey: @"SOGoMailCertificate"];
+}
+
+- (NSString *) mailCertificate
+{
+  return [self stringForKey: @"SOGoMailCertificate"];
+}
+
+- (void) setMailCertificateAlwaysSign: (BOOL) newValue
+{
+  [self setBool: newValue forKey: @"SOGoMailCertificateAlwaysSign"];
+}
+
+- (BOOL) mailCertificateAlwaysSign
+{
+  return [self boolForKey: @"SOGoMailCertificateAlwaysSign"];
+}
+
+- (void) setMailCertificateAlwaysEncrypt: (BOOL) newValue
+{
+  [self setBool: newValue forKey: @"SOGoMailCertificateAlwaysEncrypt"];
+}
+
+- (BOOL) mailCertificateAlwaysEncrypt
+{
+  return [self boolForKey: @"SOGoMailCertificateAlwaysEncrypt"];
+}
+
 - (void) setAuxiliaryMailAccounts: (NSArray *) newAccounts
 {
   [self setObject: newAccounts forKey: @"AuxiliaryMailAccounts"];
@@ -828,7 +873,6 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
   return [self objectForKey: @"SOGoMailLabelsColors"];
 }
 
-
 - (void) setSieveFilters: (NSArray *) newValue
 {
   [self setObject: newValue forKey: @"SOGoSieveFilters"];
