@@ -1,8 +1,6 @@
 /* sogo-tool.m - this file is part of SOGo
  *
- * Copyright (C) 2009 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2009-2015 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,14 +21,12 @@
 #import <Foundation/NSAutoreleasePool.h>
 #import <Foundation/NSArray.h>
 #import <Foundation/NSDictionary.h>
-#import <Foundation/NSEnumerator.h>
-#import <Foundation/NSObject.h>
 #import <Foundation/NSProcessInfo.h>
-#import <Foundation/NSString.h>
 #import <Foundation/NSUserDefaults.h>
 #import <Foundation/NSValue.h>
 
 #import <SOGo/SOGoSystemDefaults.h>
+#import <SOGo/SOGoProductLoader.h>
 
 #import "SOGoTool.h"
 
@@ -151,7 +147,7 @@
                   command, [currentTool objectAtIndex: 1]];
     }
 
-  NSLog (helpString);
+  NSLog (@"%@", helpString);
 }
 
 - (void) registerTools
@@ -247,6 +243,9 @@ main (int argc, char **argv, char **env)
 
   pool = [NSAutoreleasePool new];
 
+  /* load products */
+  [[SOGoProductLoader productLoader] loadAllProducts: NO];
+
   [SOGoSystemDefaults sharedSystemDefaults];
   setupUserDefaults ();
 
