@@ -381,7 +381,8 @@ static Class SOGoContactGCSEntryK = Nil;
           o = [values objectAtIndex: i];
           if ([o isKindOfClass: [NSDictionary class]])
             {
-              element = [card elementWithTag: @"adr" ofType: [o objectForKey: @"type"]];
+              element = [CardElement elementWithTag: @"adr"];
+              [element addType: [o objectForKey: @"type"]];
               [element setSingleValue: [o objectForKey: @"postoffice"]
                               atIndex: 0 forKey: @""];
               [element setSingleValue: [o objectForKey: @"street2"]
@@ -396,6 +397,7 @@ static Class SOGoContactGCSEntryK = Nil;
                               atIndex: 5 forKey: @""];
               [element setSingleValue: [o objectForKey: @"country"]
                               atIndex: 6 forKey: @""];
+              [card addChild: element];
             }
         }
     }
@@ -508,14 +510,14 @@ static Class SOGoContactGCSEntryK = Nil;
         {
           elements = [card childrenWithTag: @"custom3"];
           [card removeChildren: elements];
-          [card addElementWithTag: @"custom1"  ofType: nil  withValue: o];
+          [card addElementWithTag: @"custom3"  ofType: nil  withValue: o];
         }
 
       if ((o = [customFields objectForKey: @"4"]))
         {
           elements = [card childrenWithTag: @"custom4"];
           [card removeChildren: elements];
-          [card addElementWithTag: @"custom1"  ofType: nil  withValue: o];
+          [card addElementWithTag: @"custom4"  ofType: nil  withValue: o];
         }
     }
 
