@@ -1,8 +1,6 @@
 /* UIxMailFolderActions.h - this file is part of SOGo
  *
- * Copyright (C) 2007 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2007-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,13 +21,13 @@
 #ifndef UIXMAILFOLDERACTIONS_H
 #define UIXMAILFOLDERACTIONS_H
 
-#import <NGObjWeb/WODirectAction.h>
+#import <UI/SOGoUI/SOGoDirectAction.h>
 
 @class WOResponse;
 
-@interface UIxMailFolderActions : WODirectAction
+@interface UIxMailFolderActions : SOGoDirectAction
 
-- (WOResponse *) createFolderAction;
+- (id <WOActionResults>) createFolderAction;
 - (WOResponse *) renameFolderAction;
 - (WOResponse *) deleteAction;
 - (WOResponse *) batchDeleteAction;
