@@ -109,7 +109,7 @@
 
   appName = [[context request] applicationName];
   date = [NSCalendarDate calendarDate];
-  [date setTimeZone: [NSTimeZone timeZoneWithAbbreviation: @"GMT"]];
+  [date setTimeZone: [NSTimeZone timeZoneForSecondsFromGMT: 0]];
   if (username)
     {
       // Cookie expires in one month
@@ -148,7 +148,7 @@
   if (cookieReset)
     {
       date = [NSCalendarDate calendarDate];
-      [date setTimeZone: [NSTimeZone timeZoneWithAbbreviation: @"GMT"]];
+      [date setTimeZone: [NSTimeZone timeZoneForSecondsFromGMT: 0]];
       [locationCookie setExpires: [date yesterday]];
     }
 
@@ -317,7 +317,9 @@
 {
   WOResponse *response;
   NSString *login, *logoutRequest, *newLocation, *oldLocation, *ticket;
+  SOGoAppointmentFolders *calendars;
   SOGoCASSession *casSession;
+  SOGoUser *loggedInUser;
   SOGoWebAuthenticator *auth;
   WOCookie *casCookie, *casLocationCookie;
   WORequest *rq;
@@ -381,6 +383,11 @@
           newLocation = [NSString stringWithFormat: @"%@%@",
                                   oldLocation, [login stringByEscapingURL]];
         }
+
+      loggedInUser = [SOGoUser userWithLogin: login];
+      calendars = [loggedInUser calendarsFolderInContext: context];
+      if ([calendars respondsToSelector: @selector (reloadWebCalendars:)])
+        [calendars reloadWebCalendars: NO];
     }
   else
     {
