@@ -1,6 +1,6 @@
 /* UIxPreferences.m - this file is part of SOGo
  *
- * Copyright (C) 2007-2018 Inverse inc.
+ * Copyright (C) 2007-2019 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -201,56 +201,6 @@ static NSArray *reminderValues = nil;
   return [[[iCalTimeZone knownTimeZoneNames] sortedArrayUsingSelector: @selector (localizedCaseInsensitiveCompare:)] jsonRepresentation];
 }
 
-// - (NSString *) userTimeZone
-// {
-//   NSString *name;
-//   iCalTimeZone *tz;
-
-//   name = [userDefaults timeZoneName];
-//   tz = [iCalTimeZone timeZoneForName: name];
-
-//   if (!tz)
-//     {
-//       // The specified timezone is not in our Olson database.
-//       // Look for a known timezone with the same GMT offset.
-//       NSString *current;
-//       NSCalendarDate *now;
-//       NSEnumerator *zones;
-//       BOOL found;
-//       unsigned int offset;
-
-//       found = NO;
-//       now = [NSCalendarDate calendarDate];
-//       offset = [[userDefaults timeZone] secondsFromGMTForDate: now];
-//       zones = [[iCalTimeZone knownTimeZoneNames] objectEnumerator];
-
-//       while ((current = [zones nextObject]))
-// 	{
-// 	  tz = [iCalTimeZone timeZoneForName: current];
-// 	  if ([[tz periodForDate: now] secondsOffsetFromGMT] == offset)
-// 	    {
-// 	      found = YES;
-// 	      break;
-// 	    }
-// 	}
-
-//       if (found)
-// 	{
-// 	  [self warnWithFormat: @"User %@ has an unknown timezone (%@) -- replaced by %@", [user login], name, current];
-// 	  name = current;
-// 	}
-//       else
-// 	[self errorWithFormat: @"User %@ has an unknown timezone (%@)", [user login], name];
-//     }
-
-//   return name;
-// }
-
-// - (void) setUserTimeZone: (NSString *) newUserTimeZone
-// {
-//   [userDefaults setTimeZoneName: newUserTimeZone];
-// }
-
 //
 // Used by wox template
 //
@@ -303,19 +253,6 @@ static NSArray *reminderValues = nil;
   return shortDateFormatText;
 }
 
-// - (NSString *) userShortDateFormat
-// {
-//   return [userDefaults shortDateFormat];
-// }
-
-// - (void) setUserShortDateFormat: (NSString *) newFormat
-// {
-//   if ([newFormat isEqualToString: @"default"])
-//     [userDefaults unsetShortDateFormat];
-//   else
-//     [userDefaults setShortDateFormat: newFormat];
-// }
-
 //
 // Used internally
 //
@@ -385,14 +322,6 @@ static NSArray *reminderValues = nil;
   return longDateFormatText;
 }
 
-// - (void) setUserLongDateFormat: (NSString *) newFormat
-// {
-//   if ([newFormat isEqualToString: @"default"])
-//     [userDefaults unsetLongDateFormat];
-//   else
-//     [userDefaults setLongDateFormat: newFormat];
-// }
-
 //
 // Used by wox template
 //
@@ -447,19 +376,6 @@ static NSArray *reminderValues = nil;
   return timeFormatText;
 }
 
-// - (NSString *) userTimeFormat
-// {
-//   return [userDefaults timeFormat];
-// }
-
-// - (void) setUserTimeFormat: (NSString *) newFormat
-// {
-//   if ([newFormat isEqualToString: @"default"])
-//     [userDefaults unsetTimeFormat];
-//   else
-//     [userDefaults setTimeFormat: newFormat];
-// }
-
 //
 // Used by wox template
 //
@@ -483,16 +399,6 @@ static NSArray *reminderValues = nil;
   return [daysOfWeek objectAtIndex: [item intValue]];
 }
 
-// - (NSString *) userWeekStartDay
-// {
-//   return [NSString stringWithFormat: @"%d", [userDefaults firstDayOfWeek]];
-// }
-
-// - (void) setUserWeekStartDay: (NSString *) newDay
-// {
-//   [userDefaults setFirstDayOfWeek: [newDay intValue]];
-// }
-
 //
 // Used by wox template
 //
@@ -513,16 +419,6 @@ static NSArray *reminderValues = nil;
   return [self labelForKey: [NSString stringWithFormat: @"%@Calendar", item]];
 }
 
-// - (NSString *) userDefaultCalendar
-// {
-//   return [userDefaults defaultCalendar];
-// }
-
-// - (void) setUserDefaultCalendar: (NSString *) newValue
-// {
-//   [userDefaults setDefaultCalendar: newValue];
-// }
-
 //
 // Used by wox template
 //
@@ -549,26 +445,6 @@ static NSArray *reminderValues = nil;
                                       item]];
 }
 
-// - (void) setEventsDefaultClassification: (NSString *) newValue
-// {
-//   [userDefaults setCalendarEventsDefaultClassification: newValue];
-// }
-
-// - (NSString *) eventsDefaultClassification
-// {
-//   return [userDefaults calendarEventsDefaultClassification];
-// }
-
-// - (void) setTasksDefaultClassification: (NSString *) newValue
-// {
-//   [userDefaults setCalendarTasksDefaultClassification: newValue];
-// }
-
-// - (NSString *) tasksDefaultClassification
-// {
-//   return [userDefaults calendarTasksDefaultClassification];
-// }
-
 //
 // Used by wox template
 //
@@ -601,40 +477,6 @@ static NSArray *reminderValues = nil;
   return text;
 }
 
-// - (void) setReminder: (NSString *) theReminder
-// {
-//   NSString *value;
-//   NSUInteger index;
-
-//   index = NSNotFound;
-//   value = @"NONE";
-
-//   if (theReminder && [theReminder caseInsensitiveCompare: @"-"] != NSOrderedSame)
-//     index = [reminderItems indexOfObject: theReminder];
-
-//   if (index != NSNotFound)
-//     value = [reminderValues objectAtIndex: index];
-
-//   [userDefaults setCalendarDefaultReminder: value];
-// }
-
-// - (NSString *) reminder
-// {
-//   NSString *value;
-//   NSUInteger index;
-
-//   value = [userDefaults calendarDefaultReminder];
-//   if (value != nil)
-//     {
-//       index = [reminderValues indexOfObject: value];
-
-//       if (index != NSNotFound)
-//         return [reminderItems objectAtIndex: index];
-//     }
-
-//   return @"NONE";
-// }
-
 //
 // Used by wox template
 //
@@ -654,89 +496,11 @@ static NSArray *reminderValues = nil;
   return hours;
 }
 
-// - (NSString *) userDayStartTime
-// {
-//   return [NSString stringWithFormat: @"%02d:00",
-//                    [userDefaults dayStartHour]];
-// }
-
-// - (void) setUserDayStartTime: (NSString *) newTime
-// {
-//   [userDefaults setDayStartTime: newTime];
-// }
-
-// - (NSString *) userDayEndTime
-// {
-//   return [NSString stringWithFormat: @"%02d:00",
-//                    [userDefaults dayEndHour]];
-// }
-
-// - (void) setUserDayEndTime: (NSString *) newTime
-// {
-//   [userDefaults setDayEndTime: newTime];
-// }
-
-// - (void) setBusyOffHours: (BOOL) busyOffHours
-// {
-//   [userDefaults setBusyOffHours: busyOffHours];
-// }
-
-// - (BOOL) busyOffHours
-// {
-//   return [userDefaults busyOffHours];
-// }
-
-// - (NSArray *) whiteList
-// {
-//   SOGoUserSettings *us;
-//   NSMutableDictionary *moduleSettings;
-//   NSArray *whiteList;
-
-//   us = [user userSettings];
-//   moduleSettings = [us objectForKey: @"Calendar"];
-//   whiteList = [moduleSettings objectForKey:@"PreventInvitationsWhitelist"];
-//   return whiteList;
-// }
-
-// - (void) setWhiteList: (NSString *) whiteListString
-// {
-//   SOGoUserSettings *us;
-//   NSMutableDictionary *moduleSettings;
-
-//   us = [user userSettings];
-//   moduleSettings = [us objectForKey: @"Calendar"];
-//   [moduleSettings setObject: whiteListString forKey: @"PreventInvitationsWhitelist"];
-//   [us synchronize];
-// }
-
-// - (void) setPreventInvitations: (BOOL) preventInvitations
-// {
-//   SOGoUserSettings *us;
-//   NSMutableDictionary *moduleSettings;
-//   us = [user userSettings];
-//   moduleSettings = [us objectForKey: @"Calendar"];
-//   [moduleSettings setObject: [NSNumber numberWithBool: preventInvitations] forKey: @"PreventInvitations"];
-//   [us synchronize];
-// }
-
-// - (BOOL) preventInvitations
-// {
-//   SOGoUserSettings *us;
-//   NSMutableDictionary *moduleSettings;
-//   us = [user userSettings];
-//   moduleSettings = [us objectForKey: @"Calendar"];
-//   return [[moduleSettings objectForKey: @"PreventInvitations"] boolValue];
-// }
-
 - (NSArray *) shortWeekDaysList
 {
-  static NSArray *shortWeekDaysList = nil;
+  NSArray *shortWeekDaysList = nil;
 
-  if (!shortWeekDaysList)
-    {
-      shortWeekDaysList = [locale objectForKey: NSShortWeekDayNameArray];
-      [shortWeekDaysList retain];
-    }
+  shortWeekDaysList = [locale objectForKey: NSShortWeekDayNameArray];
 
   return shortWeekDaysList;
 }
@@ -771,47 +535,6 @@ static NSArray *reminderValues = nil;
                                       item]];
 }
 
-// - (NSString *) userFirstWeek
-// {
-//   return [userDefaults firstWeekOfYear];
-// }
-
-// - (void) setUserFirstWeek: (NSString *) newFirstWeek
-// {
-//   [userDefaults setFirstWeekOfYear: newFirstWeek];
-// }
-
-/* Mailer */
-// - (void) setAddOutgoingAddresses: (BOOL) addOutgoingAddresses
-// {
-//   [userDefaults setMailAddOutgoingAddresses: addOutgoingAddresses];
-// }
-
-// - (BOOL) addOutgoingAddresses
-// {
-//   return [userDefaults mailAddOutgoingAddresses];
-// }
-
-// - (void) setShowSubscribedFoldersOnly: (BOOL) showSubscribedFoldersOnly
-// {
-//   [userDefaults setMailShowSubscribedFoldersOnly: showSubscribedFoldersOnly];
-// }
-
-// - (BOOL) showSubscribedFoldersOnly
-// {
-//   return [userDefaults mailShowSubscribedFoldersOnly];
-// }
-
-// - (void) setSortByThreads: (BOOL) sortByThreads
-// {
-//   [userDefaults setMailSortByThreads: sortByThreads];
-// }
-
-// - (BOOL) sortByThreads
-// {
-//   return [userDefaults mailSortByThreads];
-// }
-
 //
 // Used by wox template
 //
@@ -864,16 +587,6 @@ static NSArray *reminderValues = nil;
   return localAddressBooks;
 }
 
-// - (NSString *) userAddressBook
-// {
-//   return [userDefaults selectedAddressBook];
-// }
-
-// - (void) setUserAddressBook: (NSString *) newSelectedAddressBook
-// {
-//   [userDefaults setSelectedAddressBook: newSelectedAddressBook];
-// }
-
 //
 // Used by wox template
 //
@@ -918,16 +631,6 @@ static NSArray *reminderValues = nil;
   return [self labelForKey: [NSString stringWithFormat: @"refreshview_%@", item]];
 }
 
-// - (NSString *) userRefreshViewCheck
-// {
-//   return [userDefaults refreshViewCheck];
-// }
-
-// - (void) setUserRefreshViewCheck: (NSString *) newRefreshViewCheck
-// {
-//   [userDefaults setRefreshViewCheck: newRefreshViewCheck];
-// }
-
 //
 // Used by wox template
 //
@@ -945,16 +648,6 @@ static NSArray *reminderValues = nil;
                  [NSString stringWithFormat: @"messageforward_%@", item]];
 }
 
-// - (NSString *) userMessageForwarding
-// {
-//   return [userDefaults mailMessageForwarding];
-// }
-
-// - (void) setUserMessageForwarding: (NSString *) newMessageForwarding
-// {
-//   [userDefaults setMailMessageForwarding: newMessageForwarding];
-// }
-
 //
 // Used by wox template
 //
@@ -972,16 +665,6 @@ static NSArray *reminderValues = nil;
                  [NSString stringWithFormat: @"replyplacement_%@", item]];
 }
 
-// - (NSString *) userReplyPlacement
-// {
-//   return [userDefaults mailReplyPlacement];
-// }
-
-// - (void) setUserReplyPlacement: (NSString *) newReplyPlacement
-// {
-//   [userDefaults setMailReplyPlacement: newReplyPlacement];
-// }
-
 //
 // Used by wox template
 //
@@ -999,16 +682,6 @@ static NSArray *reminderValues = nil;
   return [NSArray arrayWithObjects: @"above", @"below", nil];
 }
 
-// - (void) setUserSignaturePlacement: (NSString *) newSignaturePlacement
-// {
-//   [userDefaults setMailSignaturePlacement: newSignaturePlacement];
-// }
-
-// - (NSString *) userSignaturePlacement
-// {
-//   return [userDefaults mailSignaturePlacement];
-// }
-
 //
 // Used by wox template
 //
@@ -1026,16 +699,6 @@ static NSArray *reminderValues = nil;
                                         @"composemessagestype_%@", item]];
 }
 
-// - (NSString *) userComposeMessagesType
-// {
-//   return [userDefaults mailComposeMessageType];
-// }
-
-// - (void) setUserComposeMessagesType: (NSString *) newType
-// {
-//   [userDefaults setMailComposeMessageType: newType];
-// }
-
 //
 // Used by wox template
 //
@@ -1053,26 +716,6 @@ static NSArray *reminderValues = nil;
                                         @"displayremoteinlineimages_%@", item]];
 }
 
-// - (NSString *) userDisplayRemoteInlineImages
-// {
-//   return [userDefaults mailDisplayRemoteInlineImages];
-// }
-
-// - (void) setAutoSave: (NSString *) theValue
-// {
-//   [userDefaults setMailAutoSave: theValue];
-// }
-
-// - (NSString *) autoSave
-// {
-//   return [userDefaults mailAutoSave];
-// }
-
-// - (void) setUserDisplayRemoteInlineImages: (NSString *) newType
-// {
-//   [userDefaults setMailDisplayRemoteInlineImages: newType];
-// }
-
 //
 // Used by wox template
 //
@@ -1108,6 +751,11 @@ static NSArray *reminderValues = nil;
   return [[user domainDefaults] vacationEnabled];
 }
 
+- (BOOL) isVacationPeriodEnabled
+{
+  return [[user domainDefaults] vacationPeriodEnabled];
+}
+
 - (NSString *) vacationHeader
 {
   NSString *path;
@@ -1142,54 +790,6 @@ static NSArray *reminderValues = nil;
   return text;
 }
 
-// - (void) setSieveFiltersValue: (NSString *) newValue
-// {
-//   sieveFilters = [newValue objectFromJSONString];
-//   if (sieveFilters)
-//     {
-//       if ([sieveFilters isKindOfClass: [NSArray class]])
-//         [sieveFilters retain];
-//       else
-//         sieveFilters = nil;
-//     }
-// }
-
-// - (NSString *) sieveFiltersValue
-// {
-//   return [sieveFilters jsonRepresentation];
-// }
-
-// - (void) setEnableVacation: (BOOL) enableVacation
-// {
-//   [vacationOptions setObject: [NSNumber numberWithBool: enableVacation]
-//                       forKey: @"enabled"];
-// }
-
-// - (BOOL) enableVacation
-// {
-//   return [[vacationOptions objectForKey: @"enabled"] boolValue];
-// }
-
-// - (void) setAutoReplyText: (NSString *) theText
-// {
-//   [vacationOptions setObject: theText forKey: @"autoReplyText"];
-// }
-
-// - (NSString *) autoReplyText
-// {
-//   return [vacationOptions objectForKey: @"autoReplyText"];
-// }
-
-// - (void) setAutoReplyEmailAddresses: (NSString *) theAddresses
-// {
-//   NSArray *addresses;
-
-//   addresses = [[theAddresses componentsSeparatedByString: @","]
-//                 trimmedComponents];
-//   [vacationOptions setObject: addresses
-// 		      forKey: @"autoReplyEmailAddresses"];
-// }
-
 //
 // Used internally
 //
@@ -1334,105 +934,6 @@ static NSArray *reminderValues = nil;
   return daysBetweenResponses;
 }
 
-// - (void) setDaysBetweenResponses: (NSNumber *) theDays
-// {
-//   [vacationOptions setObject: theDays
-// 		      forKey: @"daysBetweenResponse"];
-// }
-
-// - (NSString *) daysBetweenResponses
-// {
-//   NSString *days;
-
-//   days = [vacationOptions objectForKey: @"daysBetweenResponse"];
-//   if (!days)
-//     days = @"7"; // defaults to 7 days
-
-//   return days;
-// }
-
-// - (void) setIgnoreLists: (BOOL) ignoreLists
-// {
-//   [vacationOptions setObject: [NSNumber numberWithBool: ignoreLists]
-// 		      forKey: @"ignoreLists"];
-// }
-
-// - (BOOL) ignoreLists
-// {
-//   NSNumber *obj;
-//   BOOL ignore;
-
-//   obj = [vacationOptions objectForKey: @"ignoreLists"];
-
-//   if (obj == nil)
-//     ignore = YES; // defaults to YES
-//   else
-//     ignore = [obj boolValue];
-
-//   return ignore;
-// }
-
-//
-// See http://sogo.nu/bugs/view.php?id=2332 for details
-//
-// - (void) setAlwaysSend: (BOOL) ignoreLists
-// {
-//   [vacationOptions setObject: [NSNumber numberWithBool: ignoreLists]
-// 		      forKey: @"alwaysSend"];
-// }
-
-// - (BOOL) alwaysSend
-// {
-//   NSNumber *obj;
-//   BOOL ignore;
-
-//   obj = [vacationOptions objectForKey: @"alwaysSend"];
-
-//   if (obj == nil)
-//     ignore = NO; // defaults to NO
-//   else
-//     ignore = [obj boolValue];
-
-//   return ignore;
-// }
-
-// - (BOOL) enableVacationEndDate
-// {
-//   return [[vacationOptions objectForKey: @"endDateEnabled"] boolValue];
-// }
-
-// - (BOOL) disableVacationEndDate
-// {
-//   return ![self enableVacationEndDate];
-// }
-
-// - (void) setEnableVacationEndDate: (BOOL) enableVacationEndDate
-// {
-//   [vacationOptions setObject: [NSNumber numberWithBool: enableVacationEndDate]
-//                       forKey: @"endDateEnabled"];
-// }
-
-// - (void) setVacationEndDate: (NSCalendarDate *) endDate
-// {
-//   NSNumber *time;
-
-//   time = [NSNumber numberWithInt: [endDate timeIntervalSince1970]];
-
-//   [vacationOptions setObject: time forKey: @"endDate"];
-// }
-
-// - (NSCalendarDate *) vacationEndDate
-// {
-//   int time;
-
-//   time = [[vacationOptions objectForKey: @"endDate"] intValue];
-
-//   if (time > 0)
-//     return [NSCalendarDate dateWithTimeIntervalSince1970: time];
-//   else
-//     return [NSCalendarDate calendarDate];
-// }
-
 /* mail forward */
 
 //
@@ -1443,49 +944,6 @@ static NSArray *reminderValues = nil;
   return [[user domainDefaults] forwardEnabled];
 }
 
-// - (void) setEnableForward: (BOOL) enableForward
-// {
-//   [forwardOptions setObject: [NSNumber numberWithBool: enableForward]
-// 		     forKey: @"enabled"];
-// }
-
-// - (BOOL) enableForward
-// {
-//   return [[forwardOptions objectForKey: @"enabled"] boolValue];
-// }
-
-// - (void) setForwardAddress: (NSString *) forwardAddress
-// {
-//   NSArray *addresses;
-
-//   addresses = [[forwardAddress componentsSeparatedByString: @","]
-//                 trimmedComponents];
-//   [forwardOptions setObject: addresses
-// 		     forKey: @"forwardAddress"];
-// }
-
-// - (NSString *) forwardAddress
-// {
-//   id addresses;
-
-//   addresses = [forwardOptions objectForKey: @"forwardAddress"];
-
-//   return ([addresses respondsToSelector: @selector(componentsJoinedByString:)]
-//           ? [(NSArray *)addresses componentsJoinedByString: @", "]
-//           : (NSString *)addresses);
-// }
-
-// - (void) setForwardKeepCopy: (BOOL) keepCopy
-// {
-//   [forwardOptions setObject: [NSNumber numberWithBool: keepCopy]
-// 		     forKey: @"keepCopy"];
-// }
-
-// - (BOOL) forwardKeepCopy
-// {
-//   return [[forwardOptions objectForKey: @"keepCopy"] boolValue];
-// }
-
 - (NSString *) forwardConstraints
 {
   SOGoDomainDefaults *dd;
@@ -1495,6 +953,18 @@ static NSArray *reminderValues = nil;
   return [NSString stringWithFormat: @"%d", [dd forwardConstraints]];
 }
 
+- (NSString *) forwardConstraintsDomains
+{
+  NSMutableArray *domains;
+  SOGoDomainDefaults *dd;
+
+  dd = [[context activeUser] domainDefaults];
+  domains = [NSMutableArray array];
+  [domains addObjectsFromArray: [dd forwardConstraintsDomains]];
+
+  return [domains jsonRepresentation];
+}
+
 //
 // Used by templates
 //
@@ -1542,30 +1012,6 @@ static NSArray *reminderValues = nil;
   return [self labelForKey: item];
 }
 
-
-// - (NSString *) userDefaultModule
-// {
-//   NSString *userDefaultModule;
-
-//   if ([userDefaults rememberLastModule])
-//     userDefaultModule = @"Last";
-//   else
-//     userDefaultModule = [userDefaults loginModule];
-
-//   return userDefaultModule;
-// }
-
-// - (void) setUserDefaultModule: (NSString *) newValue
-// {
-//   if ([newValue isEqualToString: @"Last"])
-//     [userDefaults setRememberLastModule: YES];
-//   else
-//     {
-//       [userDefaults setRememberLastModule: NO];
-//       [userDefaults setLoginModule: newValue];
-//     }
-// }
-
 //
 // Used by templates
 //
@@ -1605,52 +1051,6 @@ static NSArray *reminderValues = nil;
           : NO);
 }
 
-// - (id <WOActionResults>) defaultAction
-// {
-//   id <WOActionResults> results;
-//   SOGoDomainDefaults *dd;
-//   SOGoMailAccount *account;
-//   SOGoMailAccounts *folder;
-//   WORequest *request;
-
-//   request = [context request];
-//   if ([[request method] isEqualToString: @"POST"])
-//     {
-//       dd = [[context activeUser] domainDefaults];
-//       if ([dd sieveScriptsEnabled])
-//         [userDefaults setSieveFilters: sieveFilters];
-//       if ([dd vacationEnabled])
-//         [userDefaults setVacationOptions: vacationOptions];
-//       if ([dd forwardEnabled])
-//         [userDefaults setForwardOptions: forwardOptions];
-
-//       if (!([dd sieveScriptsEnabled] || [dd vacationEnabled] || [dd forwardEnabled]) || [self _isSieveServerAvailable])
-//         {
-//           [userDefaults synchronize];
-//           folder = [[self clientObject] mailAccountsFolder: @"Mail"
-//                                                  inContext: context];
-//           account = [folder lookupName: @"0" inContext: context acquire: NO];
-
-//           if ([account updateFilters])
-//             // If Sieve is not enabled, the SOGoSieveManager will immediatly return a positive answer
-//             // See [SOGoSieveManager updateFiltersForAccount:withUsername:andPassword:]
-//             results = (id <WOActionResults>)[self responseWithStatus: 200
-//                          andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: [NSNumber numberWithBool:hasChanged], @"hasChanged", nil]];
-
-//           else
-//             results = (id <WOActionResults>)[self responseWithStatus: 502
-//                          andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: @"Connection error", @"textStatus", nil]];
-//         }
-//       else
-//         results = (id <WOActionResults>)[self responseWithStatus: 503
-//                      andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: @"Service temporarily unavailable", @"textStatus", nil]];
-//     }
-//   else
-//     results = self;
-
-//   return results;
-// }
-
 - (BOOL) shouldTakeValuesFromRequest: (WORequest *) request
                            inContext: (WOContext*) context
 {
@@ -1691,184 +1091,6 @@ static NSArray *reminderValues = nil;
            userCanChangePassword];
 }
 
-// - (NSString *) localeCode
-// {
-//   // WARNING : NSLocaleCode is not defined in <Foundation/NSUserDefaults.h>
-//   return [locale objectForKey: @"NSLocaleCode"];
-// }
-
-// - (NSArray *) _languageCalendarCategories
-// {
-//   NSArray *categoryLabels;
-
-//   categoryLabels = [[self labelForKey: @"calendar_category_labels"]
-//                        componentsSeparatedByString: @","];
-
-//   return [categoryLabels trimmedComponents];
-// }
-
-// - (NSArray *) calendarCategoryList
-// {
-//   if (!calendarCategories)
-//     {
-//       ASSIGN (calendarCategories, [userDefaults calendarCategories]);
-//       if (!calendarCategories)
-//         ASSIGN (calendarCategories, [self _languageCalendarCategories]);
-//     }
-
-//   return [calendarCategories
-//            sortedArrayUsingSelector: @selector (localizedCaseInsensitiveCompare:)];
-// }
-
-// - (SOGoMailLabel *) label
-// {
-//   return label;
-// }
-
-// - (void) setLabel: (SOGoMailLabel *) newLabel
-// {
-//   ASSIGN(label, newLabel);
-// }
-
-// - (NSArray *) mailLabelList
-// {
-//   if (!mailLabels)
-//     {
-//       NSDictionary *v;
-
-//       v = [[[context activeUser] userDefaults] mailLabelsColors];
-//       ASSIGN(mailLabels, [SOGoMailLabel labelsFromDefaults: v  component: self]);
-//     }
-
-//   return mailLabels;
-// }
-
-// - (NSString *) mailLabelsValue
-// {
-//   return @"";
-// }
-
-// - (void) setMailLabelsValue: (NSString *) value
-// {
-//   NSMutableDictionary *sanitizedLabels;
-//   NSDictionary *newLabels;
-//   NSArray *allKeys;
-//   NSString *name;
-//   int i;
-
-//   newLabels = [value objectFromJSONString];
-//   if (newLabels && [newLabels isKindOfClass: [NSDictionary class]])
-//     {
-//       // We encode correctly our keys
-//       sanitizedLabels = [NSMutableDictionary dictionary];
-//       allKeys = [newLabels allKeys];
-
-//       for (i = 0; i < [allKeys count]; i++)
-//         {
-//           name = [allKeys objectAtIndex: i];
-
-//           if (![name is7bitSafe])
-//             name = [name stringByEncodingImap4FolderName];
-
-//           name = [name lowercaseString];
-
-//           [sanitizedLabels setObject: [newLabels objectForKey: [allKeys objectAtIndex: i]]
-//                               forKey: name];
-//         }
-
-//       [userDefaults setMailLabelsColors: sanitizedLabels];
-//     }
-// }
-
-
-// - (void) setCategory: (NSString *) newCategory
-// {
-//   ASSIGN (category, newCategory);
-// }
-
-// - (NSString *) category
-// {
-//   return category;
-// }
-
-// - (NSString *) categoryColor
-// {
-//   SOGoDomainDefaults *dd;
-//   NSString *categoryColor;
-
-//   if (!calendarCategoriesColors)
-//     ASSIGN (calendarCategoriesColors, [userDefaults calendarCategoriesColors]);
-
-//   categoryColor = [calendarCategoriesColors objectForKey: category];
-//   if (!categoryColor)
-//     {
-//       if (!defaultCategoryColor)
-//         {
-//           dd = [[context activeUser] domainDefaults];
-//           ASSIGN (defaultCategoryColor, [dd calendarDefaultCategoryColor]);
-//         }
-//       categoryColor = defaultCategoryColor;
-//     }
-
-//   return categoryColor;
-// }
-
-// - (NSString *) calendarCategoriesValue
-// {
-//   return @"";
-// }
-
-// - (void) setCalendarCategoriesValue: (NSString *) value
-// {
-//   NSDictionary *newColors;
-
-//   newColors = [value objectFromJSONString];
-//   if (newColors && [newColors isKindOfClass: [NSDictionary class]])
-//     {
-//       [userDefaults setCalendarCategories: [newColors allKeys]];
-//       [userDefaults setCalendarCategoriesColors: newColors];
-//     }
-// }
-
-// - (NSArray *) _languageContactsCategories
-// {
-//   NSArray *categoryLabels;
-
-//   categoryLabels = [[self labelForKey: @"contacts_category_labels"]
-//                        componentsSeparatedByString: @","];
-//   if (!categoryLabels)
-//     categoryLabels = [NSArray array];
-
-//   return [categoryLabels trimmedComponents];
-// }
-
-// - (NSArray *) contactsCategoryList
-// {
-//   if (!contactsCategories)
-//     {
-//       ASSIGN (contactsCategories, [userDefaults contactsCategories]);
-//       if (!contactsCategories)
-//         ASSIGN (contactsCategories, [self _languageContactsCategories]);
-//     }
-
-//   return [contactsCategories
-//            sortedArrayUsingSelector: @selector (localizedCaseInsensitiveCompare:)];
-// }
-
-// - (NSString *) contactsCategoriesValue
-// {
-//   return @"";
-// }
-
-// - (void) setContactsCategoriesValue: (NSString *) value
-// {
-//   NSArray *newCategories;
-
-//   newCategories = [value objectFromJSONString];
-//   if (newCategories && [newCategories isKindOfClass: [NSArray class]])
-//     [userDefaults setContactsCategories: newCategories];
-// }
-
 //
 // Used by wox template
 //
@@ -1877,17 +1099,6 @@ static NSArray *reminderValues = nil;
   return [[SOGoSystemDefaults sharedSystemDefaults] supportedLanguages];
 }
 
-// - (NSString *) language
-// {
-//   return [userDefaults language];
-// }
-
-// - (void) setLanguage: (NSString *) newLanguage
-// {
-//   if ([[self languages] containsObject: newLanguage])
-//     [userDefaults setLanguage: newLanguage];
-// }
-
 //
 // Used by wox template
 //
@@ -1994,8 +1205,8 @@ static NSArray *reminderValues = nil;
 
   if ([receipts isKindOfClass: [NSDictionary class]])
     {
-      action = [receipts objectForKey: @"receiptAction"];
-      [target setObject: @"1" forKey: @"SOGoMailReceiptAllow"];
+      action = [[receipts objectForKey: @"receiptAction"] isEqualToString: @"ignore"] ? @"0" : @"1";
+      [target setObject: action forKey: @"SOGoMailReceiptAllow"];
 
       action = [receipts objectForKey: @"receiptNonRecipientAction"];
       if ([self _validateReceiptAction: action])
@@ -2258,41 +1469,6 @@ static NSArray *reminderValues = nil;
     }
 }
 
-// - (void) setMailAccounts: (NSString *) newMailAccounts
-// {
-//   NSArray *accounts;
-//   int max;
-
-//   accounts = [newMailAccounts objectFromJSONString];
-//   if (accounts && [accounts isKindOfClass: [NSArray class]])
-//     {
-//       max = [accounts count];
-//       if (max > 0)
-//         {
-//           [self _extractMainAccountSettings: [accounts objectAtIndex: 0]];
-//           if ([self mailAuxiliaryUserAccountsEnabled])
-//             [self _extractAuxiliaryAccounts: accounts];
-//         }
-//     }
-// }
-
-// - (NSString *) mailAccounts
-// {
-//   NSArray *accounts;
-//   NSMutableDictionary *account;
-//   int count, max;
-
-//   accounts = [user mailAccounts];
-//   max = [accounts count];
-//   for (count = 0; count < max; count++)
-//     {
-//       account = [accounts objectAtIndex: count];
-//       [account removeObjectForKey: @"password"];
-//     }
-
-//   return [accounts jsonRepresentation];
-// }
-
 - (NSString *) mailCustomFromEnabled
 {
   return (mailCustomFromEnabled ? @"true" : @"false");
@@ -2437,6 +1613,7 @@ static NSArray *reminderValues = nil;
 
       if ([[user userDefaults] synchronize])
         {
+          NSException *error;
           SOGoMailAccount *account;
           SOGoMailAccounts *folder;
           SOGoDomainDefaults *dd;
@@ -2446,15 +1623,16 @@ static NSArray *reminderValues = nil;
           // We check if the Sieve server is available *ONLY* if at least one of the option is enabled
           if (!([dd sieveScriptsEnabled] || [dd vacationEnabled] || [dd forwardEnabled]) || [self _isSieveServerAvailable])
             {
+              BOOL forceActivation = ![[v objectForKey: @"hasActiveExternalSieveScripts"] boolValue];
 
               folder = [[[context activeUser] homeFolderInContext: context]  mailAccountsFolder: @"Mail"
                                                                                       inContext: context];
               account = [folder lookupName: @"0" inContext: context acquire: NO];
 
-              if (![account updateFilters])
+              if ((error = [account updateFiltersAndForceActivation: forceActivation]))
                 {
-                  results = (id <WOActionResults>) [self responseWithStatus: 502
-                           andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: @"Connection error", @"message", nil]];
+                  results = (id <WOActionResults>) [self responseWithStatus: 500
+                                                      andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: [error reason], @"message", nil]];
                 }
             }
           else
