@@ -1,14 +1,14 @@
 /*
-  Copyright (C) 2000-2005 SKYRIX Software AG
+  Copyright (C) 2007-2019 Inverse inc.
 
-  This file is part of OpenGroupware.org.
+  This file is part of SOGo
 
-  OGo is free software; you can redistribute it and/or modify it under
+  SOGo is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.
 
-  OGo is distributed in the hope that it will be useful, but WITHOUT ANY
+  SOGo is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
   License for more details.
@@ -43,8 +43,10 @@
   NSCalendarDate *_selectedDate;
   NSDictionary *locale;
   SOGoUserDefaults *userDefaults;
+  NSArray *languages;
 }
 
++ (NSArray *) amPmLabelKeys;
 + (NSArray *) monthLabelKeys;
 + (NSArray *) abbrMonthLabelKeys;
 
@@ -83,6 +85,10 @@
 /* SoUser */
 - (NSString *) shortUserNameForDisplay;
 
+/* Common defaults and settings */
+- (int) minimumSearchLength;
+- (NSString *) minimumSearchLengthLabel;
+
 /* labels */
 - (NSString *) labelForKey:(NSString *)_key;
 - (NSString *) commonLabelForKey:(NSString *)_key;
@@ -102,6 +108,7 @@
     
 /* locale */
 - (NSDictionary *)locale;
+- (NSString *) localeCode;
 
 /* cached resource filenames */
 - (WOResourceManager *) pageResourceManager;
