@@ -37,10 +37,13 @@
 {
   SOGoDateFormatter *dateFormatter;
   NSArray *weekDays;
-  NSString *currentView, *timeFormat, *currentTableHour;
+  NSString *currentView, *timeFormat;
+  NSNumber *currentTableHour;
   NSCalendarDate *startDate, *currentTableDay;
-  NSMutableArray *daysToDisplay, *calendarsToDisplay,  *currentCalendar, *hoursToDisplay;
+  NSMutableArray *daysToDisplay, *calendarsToDisplay, *hoursToDisplay;
+  NSMutableDictionary *currentCalendar;
   unsigned int numberOfDays;
+  unsigned int *daysNumbersToDisplay;
 }
 
 - (void) setNumberOfDays: (NSNumber *) aNumber;
@@ -55,7 +58,7 @@
 - (NSArray *) calendarsToDisplay;
 - (void) setCurrentTableDay: (NSCalendarDate *) aTableDay;
 - (NSCalendarDate *) currentTableDay;
-- (NSMutableArray *) currentCalendar;
+- (NSMutableDictionary *) currentCalendar;
 
 @end
 
