@@ -1,6 +1,6 @@
 /* UIxCalMainView.m - this file is part of SOGo
  *
- * Copyright (C) 2006-2018 Inverse inc.
+ * Copyright (C) 2006-2019 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -339,6 +339,22 @@
   return (view ? view : @"weekview");
 }
 
+- (NSArray *) repeatFrequencies
+{
+  NSArray *repeatFrequencies;
+
+  repeatFrequencies = [NSArray arrayWithObjects:
+                                 [NSArray arrayWithObjects: @"never", [self labelForKey: @"repeat_NEVER"], nil],
+                               [NSArray arrayWithObjects:  @"daily",[self labelForKey: @"repeat_DAILY"], nil],
+                               [NSArray arrayWithObjects: @"weekly",[self labelForKey: @"repeat_WEEKLY"],  nil],
+                               [NSArray arrayWithObjects: @"monthly",[self labelForKey: @"repeat_MONTHLY"],  nil],
+                               [NSArray arrayWithObjects: @"yearly", [self labelForKey: @"repeat_YEARLY"], nil],
+                               [NSArray arrayWithObjects: @"custom", [self labelForKey: @"repeat_CUSTOM"], nil],
+                               nil];
+
+  return repeatFrequencies;
+}
+
 @end
 
 /* Component Viewer, parent class of Appointment Viewer and Task Viewer */
