@@ -65,12 +65,17 @@
    * @returns the list of accounts
    */
   Account.$findAll = function(data) {
-    if (!data) {
+    if (data) {
+      return Account.$unwrapCollection(data);
+    }
+    else if (Account.$accounts) {
+      return Account.$q.when(Account.$accounts);
+    }
+    else {
       return Account.$$resource.fetch('', 'mailAccounts').then(function(o) {
         return Account.$unwrapCollection(o);
       });
     }
-    return Account.$unwrapCollection(data);
   };
 
   /**
@@ -128,13 +133,16 @@
    * @returns a promise of the HTTP operation
    */
   Account.prototype.$getMailboxes = function(options) {
-    var _this = this;
+    var _this = this, reload = (options && options.reload);
 
-    if (this.$mailboxes && !(options && options.reload)) {
+    if (this.$mailboxes && !reload) {
       return Account.$q.when(this.$mailboxes);
     }
+    else if (!reload && this.$futureMailboxesData) {
+      return this.$futureMailboxesData;
+    }
     else {
-      return Account.$Mailbox.$find(this, options).then(function(data) {
+      this.$futureMailboxesData = Account.$Mailbox.$find(this, options).then(function(data) {
         _this.$mailboxes = data;
         _this.$expanded = false;
 
@@ -174,6 +182,7 @@
 
         return _this.$mailboxes;
       });
+      return this.$futureMailboxesData;
     }
   };
 
