@@ -46,10 +46,11 @@
 
       // Update window's title with unseen messages count of selected mailbox
       $scope.$watch(function() { return vm.selectedFolder.unseenCount; }, function(unseenCount) {
-        var title = defaultWindowTitle + ' - ';
+        var title = '';
         if (unseenCount)
           title += '(' + unseenCount + ') ';
         title += vm.selectedFolder.$displayName;
+        title += ' | ' + defaultWindowTitle;
         $window.document.title = title;
       });
     };
@@ -148,9 +149,11 @@
       return Mailbox.$query.asc;
     };
 
-    this.searchMode = function() {
+    this.searchMode = function($event) {
       vm.mode.search = true;
       focus('search');
+      if ($event)
+        $event.preventDefault();
     };
 
     this.cancelSearch = function() {
@@ -169,7 +172,7 @@
     };
 
     this.newMessage = function($event, inPopup) {
-      var message;
+      var message, onCompleteDeferred = $q.defer();
 
       if (vm.messageDialog === null) {
         if (inPopup || Preferences.defaults.SOGoMailComposeWindow == 'popup')
@@ -185,9 +188,16 @@
               templateUrl: 'UIxMailEditor',
               controller: 'MessageEditorController',
               controllerAs: 'editor',
+              onComplete: function (scope, element) {
+                return onCompleteDeferred.resolve(element);
+              },
               locals: {
+                stateParent: $scope,
                 stateAccount: vm.account,
-                stateMessage: message
+                stateMessage: message,
+                onCompletePromise: function () {
+                  return onCompleteDeferred.promise;
+                }
               }
             })
             .catch(_.noop) // Cancel
@@ -207,7 +217,6 @@
                  'new']
           .join('/'),
           wId = vm.selectedFolder.$id() + '/' + Math.random(0, 1000);
-      console.debug(url);
       $window.open(url, wId,
                    ["width=680",
                     "height=520",
