@@ -190,7 +190,7 @@
   stateMailbox.$inject = ['$q', '$stateParams', 'stateAccount', 'decodeUriFilter', 'Mailbox'];
   function stateMailbox($q, $stateParams, stateAccount, decodeUriFilter, Mailbox) {
     var mailbox,
-        mailboxId = decodeUriFilter($stateParams.mailboxId),
+        mailboxId = decodeUriFilter(decodeUriFilter($stateParams.mailboxId)),
         _find;
 
     // Recursive find function
@@ -211,16 +211,18 @@
     if (Mailbox.selectedFolder && !Mailbox.$virtualMode)
       Mailbox.selectedFolder.$isLoading = true;
 
-    mailbox = _find(stateAccount.$mailboxes);
-
-    if (mailbox) {
-      mailbox.$topIndex = 0;
-      mailbox.selectFolder();
-      return mailbox;
-    }
-    else
-      // Mailbox not found
-      return $q.reject("Mailbox doesn't exist");
+    return stateAccount.$getMailboxes().then(function (mailboxes) {
+      mailbox = _find(mailboxes);
+      if (mailbox) {
+        mailbox.$topIndex = 0;
+        mailbox.selectFolder();
+        return mailbox;
+      }
+      else {
+        // Mailbox not found
+        $state.go('mail.account', { accountId: stateMailbox.$account.id });
+      }
+    });
   }
 
   /**
