@@ -340,13 +340,22 @@
               };
             }
             else if (part.type == 'UIxMailPartEncryptedViewer') {
-              _this.encrypted = {
-                valid: part.valid
-              };
-              if (part.valid)
-                _this.encrypted.message = l("This message is encrypted");
-              else
-                _this.encrypted.message = l("This message can't be decrypted. Please make sure you have uploaded your S/MIME certificate from the mail preferences module.");
+              if (part.encrypted) {
+                _this.encrypted = {
+                  valid: part.decrypted
+                };
+                if (part.decrypted)
+                  _this.encrypted.message = l("This message is encrypted");
+                else
+                  _this.encrypted.message = l("This message can't be decrypted. Please make sure you have uploaded your S/MIME certificate from the mail preferences module.");
+              }
+              if (part.opaqueSigned) {
+                _this.signed = {
+                  valid: part.valid,
+                  certificate: part.certificates[part.certificates.length - 1],
+                  message: part.message
+                };
+              }
             }
             _.forEach(part.content, function(mixedPart) {
               _visit(mixedPart);
@@ -736,7 +745,7 @@
    */
   Message.prototype.$save = function() {
     var _this = this,
-        data = this.editable;
+        data = this.$omit();
 
     Message.$log.debug('save = ' + JSON.stringify(data, undefined, 2));
 
@@ -756,7 +765,7 @@
    */
   Message.prototype.$send = function() {
     var _this = this,
-        data = angular.copy(this.editable);
+        data = this.$omit();
 
     Message.$log.debug('send = ' + JSON.stringify(data, undefined, 2));
 
@@ -818,9 +827,15 @@
    */
   Message.prototype.$omit = function(options) {
     var message = {},
-        privateAttributes = options && options.privateAttributes;
-    angular.forEach(this, function(value, key) {
-      if (key != 'constructor' && key[0] != '$' || privateAttributes) {
+        privateAttributes = options && options.privateAttributes,
+        source = privateAttributes ? this : this.editable;
+    angular.forEach(source, function(value, key) {
+      if (_.includes(['to', 'cc', 'bcc'], key) && !privateAttributes) {
+        message[key] = _.map(value, function (addr) {
+          return addr.toString();
+        });
+      }
+      else if (key != 'constructor' && key[0] != '$' || privateAttributes) {
         message[key] = value;
       }
     });
