@@ -11,7 +11,7 @@
     var _this = this, defaultsElement, settingsElement, data;
 
     this.defaults = {};
-    this.settings = {};
+    this.settings = {Mail: {}};
 
     defaultsElement = Preferences.$document[0].getElementById('UserDefaults');
     if (defaultsElement) {
@@ -158,7 +158,7 @@
         dateString = dateString.trim();
         // The default function of Angular Material doesn't handle non-latin characters.
         // This one does.
-        var re = /^((([a-zA-Z]|[^\x00-\x7F]){3,}|[0-9]{1,4})([ .,]+|[/-])){2}(([a-zA-Z]|[^\x00-\x7F]){3,}|[0-9]{1,4})$/;
+        var re = /^((([a-zA-Z]|[^\x00-\x7F]){2,}|[0-9]{1,4})([ .,]+|[/-])){2}(([a-zA-Z]|[^\x00-\x7F]){3,}|[0-9]{1,4})$/;
         return re.test(dateString);
       };
     }
