@@ -54,10 +54,14 @@
     };
 
     this.addCalendarCategory = function(form) {
-      this.preferences.defaults.SOGoCalendarCategories.push(l('New category'));
-      this.preferences.defaults.SOGoCalendarCategoriesColorsValues.push("#aaa");
-      focus('calendarCategory_' + (this.preferences.defaults.SOGoCalendarCategories.length - 1));
-      form.$setDirty();
+      var i = _.indexOf(this.preferences.defaults.SOGoCalendarCategories, l('New category'));
+      if (i < 0) {
+        this.preferences.defaults.SOGoCalendarCategories.push(l('New category'));
+        this.preferences.defaults.SOGoCalendarCategoriesColorsValues.push("#aaa");
+        form.$setDirty();
+        i = this.preferences.defaults.SOGoCalendarCategories.length - 1;
+      }
+      focus('calendarCategory_' + i);
     };
 
     this.resetCalendarCategoryValidity = function(index, form) {
@@ -280,6 +284,11 @@
       });
     };
 
+    this.manageSieveScript = function(form) {
+      this.preferences.defaults.hasActiveExternalSieveScripts = false;
+      form.$setDirty();
+    };
+
     this.confirmChanges = function($event, form) {
       var target;
 
@@ -343,6 +352,12 @@
             Dialog.alert(l('Error'), l("You are not allowed to forward your messages to an internal email address."));
             sendForm = false;
           }
+          else if ($window.forwardConstraints == 2 &&
+                   $window.forwardConstraintsDomains.length > 0 &&
+                   $window.forwardConstraintsDomains.indexOf(domain) < 0) {
+            Dialog.alert(l('Error'), l("You are not allowed to forward your messages to this domain:") + " " + domain);
+            sendForm = false;
+          }
         }
       }
 
@@ -376,6 +391,20 @@
         });
       }
 
+      // Contact categories must be unique
+      if (this.preferences.defaults.SOGoContactsCategories.length !=
+          _.uniq(this.preferences.defaults.SOGoContactsCategories).length) {
+        Dialog.alert(l('Error'), l("Contact categories must have unique names."));
+        _.forEach(this.preferences.defaults.SOGoContactsCategories, function (value, i, keys) {
+          if (form['contactCategory_' + i].$dirty &&
+              (keys.indexOf(value) != i ||
+               keys.indexOf(value, i+1) > -1)) {
+            form['contactCategory_' + i].$setValidity('duplicate', false);
+            sendForm = false;
+          }
+        });
+      }
+
       if (sendForm)
         return this.preferences.$save().then(function(data) {
           if (!options || !options.quick) {
@@ -448,7 +477,10 @@
 
       if (v.startDateEnabled) {
         // Enabling the start date
-        if (v.endDateEnabled && v.startDate.getTime() > v.endDate.getTime()) {
+        if (!v.startDate) {
+          v.startDate = new Date();
+        }
+        if (v.endDateEnabled && v.endDate && v.startDate.getTime() > v.endDate.getTime()) {
           v.startDate = new Date(v.endDate.getTime());
           v.startDate.addDays(-1);
         }
@@ -462,7 +494,10 @@
 
       if (v.endDateEnabled) {
         // Enabling the end date
-        if (v.startDateEnabled && v.endDate.getTime() < v.startDate.getTime()) {
+        if (!v.endDate) {
+          v.endDate = new Date();
+        }
+        if (v.startDateEnabled && v.startDate && v.endDate.getTime() < v.startDate.getTime()) {
           v.endDate = new Date(v.startDate.getTime());
           v.endDate.addDays(1);
         }
@@ -476,8 +511,8 @@
           d.Vacation.enabled) {
         if (d.Vacation.startDateEnabled) {
           r = (!d.Vacation.endDateEnabled ||
-               date.getTime() < d.Vacation.endDate.getTime()) &&
-            date.getTime() >= today.getTime();
+               !d.Vacation.endDate ||
+               date.getTime() <= d.Vacation.endDate.getTime());
         }
       }
 
@@ -491,8 +526,8 @@
           d.Vacation.enabled) {
         if (d.Vacation.endDateEnabled) {
           r = (!d.Vacation.startDateEnabled ||
-               date.getTime() > d.Vacation.startDate.getTime()) &&
-            date.getTime() >= today.getTime();
+               !d.Vacation.startDate ||
+               date.getTime() >= d.Vacation.startDate.getTime());
         }
       }
 
