@@ -23,6 +23,7 @@
     this.slotEndTimeLimit.setMinutes(0);
     this.slotEndTimeLimit.setHours(Attendees.dayEndHour);
     this.$days = [];
+    this.$futureFreebusyData = {};
     this.updateFreeBusyCoverage();
     this.updateFreeBusy();
   }
@@ -170,6 +171,7 @@
           domain: card.c_domain,
           isMSExchange: card.ismsexchange,
           isGroup: card.$isList(),
+          isExpandableGroup: false,
           isResource: card.isresource,
           name: card.c_cn,
           email: card.$$email,
@@ -180,9 +182,18 @@
         if (!_.find(this.attendees, function(o) {
           return o.email == attendee.email;
         })) {
+          if (card.$isList() && Attendees.$Preferences.defaults.SOGoLDAPGroupExpansionEnabled) {
+            // LDAP list -- preload members
+            card.$members().then(function(members) {
+              attendee.members = members;
+              attendee.isExpandableGroup = true;
+            });
+          }
           attendee.image = Attendees.$gravatar(attendee.email, 32);
-          if (this.component.attendees)
-            this.component.attendees.push(attendee);
+          if (this.component.attendees) {
+            if (_.findIndex(this.component.attendees, { email: attendee.email }) < 0)
+              this.component.attendees.push(attendee);
+          }
           else
             this.component.attendees = [attendee];
           this.updateFreeBusyAttendee(attendee);
@@ -231,7 +242,9 @@
     var index = _.findIndex(this.component.attendees, function(currentAttendee) {
       return currentAttendee.email == attendee.email;
     });
-    this.component.attendees.splice(index, 1);
+    if (index > -1)
+      this.component.attendees.splice(index, 1);
+    delete this.$futureFreebusyData[attendee.uid];
   };
 
   /**
@@ -261,7 +274,9 @@
       roundedStart.setMinutes(15*startQuarter);
       roundedEnd.setMinutes(15*endQuarter);
 
-      _.forEach(roundedStart.daysUpTo(roundedEnd), function(date, index) {
+      _.forEach(roundedStart.beginOfDay().daysUpTo(roundedEnd.beginOfDay()), function(date, index) {
+        if (date < roundedStart)
+          date = new Date(roundedStart.getTime());
         var currentDay = date.getDate(),
             dayKey = date.getDayString(),
             hourKey;
@@ -432,6 +447,8 @@
         promise = Attendees.$q.when();
       }
 
+      this.$futureFreebusyData[attendee.uid] = promise;
+
       return promise;
     }
   };
